@@ -23,12 +23,9 @@ along with this program. If not, see <https://www.gnu.org/licenses/>.
 """
 from __future__ import annotations
 
-from PyQt5.QtCore import Qt
-from PyQt5.QtGui import (
-    QColor, QFont, QPainter, QTextBlockFormat, QTextCharFormat, QTextCursor,
-    QTextFormat
-)
-from PyQt5.QtWidgets import QDialog, QDialogButtonBox, QHeaderView, QSizePolicy, QStyle
+from PyQt6.QtCore import Qt
+from PyQt6.QtGui import QColor, QFont, QPainter, QTextCharFormat, QTextCursor, QTextFormat
+from PyQt6.QtWidgets import QDialog, QDialogButtonBox, QHeaderView, QSizePolicy, QStyle
 
 # Qt Alignment Flags
 
@@ -55,8 +52,9 @@ QtVAlignSuper = QTextCharFormat.VerticalAlignment.AlignSuperScript
 
 QtPageBreakBefore = QTextFormat.PageBreakFlag.PageBreak_AlwaysBefore
 QtPageBreakAfter = QTextFormat.PageBreakFlag.PageBreak_AlwaysAfter
+QtPageBreakAuto = QTextFormat.PageBreakFlag.PageBreak_Auto
 
-QtPropLineHeight = QTextBlockFormat.LineHeightTypes.ProportionalHeight
+QtPropLineHeight = 1  # QTextBlockFormat.LineHeightTypes.ProportionalHeight
 
 # Qt Painter Types
 
@@ -73,6 +71,7 @@ QtSelected = QStyle.StateFlag.State_Selected
 # Qt Colour Types
 
 QtHexRgb = QColor.NameFormat.HexRgb
+QtHexArgb = QColor.NameFormat.HexArgb
 
 # Qt Tree and Table Types
 
